@@ -1,4 +1,3 @@
-
 //! Create a codespace in a repository
 //! 
 //! Creates a codespace owned by the authenticated user in the specified repository.
@@ -203,42 +202,6 @@ impl From<::reqwest::blocking::Body> for Content<::reqwest::blocking::Body> {
     }
 }
 
-#[cfg(feature = "hyper")]
-impl<'a> TryFrom<&::std::option::Option<crate::v1_1_4::request::codespaces_create_with_repo_for_authenticated_user::body::Json<'a>>> for Content<::hyper::Body> {
-    type Error = crate::v1_1_4::ApiError;
-
-    fn try_from(value: &::std::option::Option<crate::v1_1_4::request::codespaces_create_with_repo_for_authenticated_user::body::Json<'a>>) -> Result<Self, Self::Error> {
-        Ok(
-            Self::new(::serde_json::to_vec(value)?.into())
-            .with_content_type(&b"application/json"[..])
-        )
-    }
-}
-
-#[cfg(feature = "reqwest")]
-impl<'a> TryFrom<&::std::option::Option<crate::v1_1_4::request::codespaces_create_with_repo_for_authenticated_user::body::Json<'a>>> for Content<::reqwest::Body> {
-    type Error = crate::v1_1_4::ApiError;
-
-    fn try_from(value: &::std::option::Option<crate::v1_1_4::request::codespaces_create_with_repo_for_authenticated_user::body::Json<'a>>) -> Result<Self, Self::Error> {
-        Ok(
-            Self::new(::serde_json::to_vec(value)?.into())
-            .with_content_type(&b"application/json"[..])
-        )
-    }
-}
-
-#[cfg(feature = "reqwest-blocking")]
-impl<'a> TryFrom<&::std::option::Option<crate::v1_1_4::request::codespaces_create_with_repo_for_authenticated_user::body::Json<'a>>> for Content<::reqwest::blocking::Body> {
-    type Error = crate::v1_1_4::ApiError;
-
-    fn try_from(value: &::std::option::Option<crate::v1_1_4::request::codespaces_create_with_repo_for_authenticated_user::body::Json<'a>>) -> Result<Self, Self::Error> {
-        Ok(
-            Self::new(::serde_json::to_vec(value)?.into())
-            .with_content_type(&b"application/json"[..])
-        )
-    }
-}
-
 /// Types for body parameter in [`super::codespaces_create_with_repo_for_authenticated_user`]
 pub mod body {
     #[allow(non_snake_case)]
@@ -271,4 +234,40 @@ pub mod body {
         #[serde(flatten)]
         pub additionalProperties: ::std::collections::HashMap<::std::borrow::Cow<'a, str>, ::serde_json::value::Value>
     }
+
+    #[cfg(feature = "hyper")]
+    impl<'a> TryFrom<&::std::option::Option<crate::v1_1_4::request::codespaces_create_with_repo_for_authenticated_user::body::Json<'a>>> for super::Content<::hyper::Body> {
+        type Error = crate::v1_1_4::ApiError;
+
+        fn try_from(value: &::std::option::Option<crate::v1_1_4::request::codespaces_create_with_repo_for_authenticated_user::body::Json<'a>>) -> Result<Self, Self::Error> {
+            Ok(
+                Self::new(::serde_json::to_vec(value)?.into())
+                .with_content_type(&b"application/json"[..])
+            )
+        }
+    }
+
+    #[cfg(feature = "reqwest")]
+    impl<'a> TryFrom<&::std::option::Option<crate::v1_1_4::request::codespaces_create_with_repo_for_authenticated_user::body::Json<'a>>> for super::Content<::reqwest::Body> {
+        type Error = crate::v1_1_4::ApiError;
+
+        fn try_from(value: &::std::option::Option<crate::v1_1_4::request::codespaces_create_with_repo_for_authenticated_user::body::Json<'a>>) -> Result<Self, Self::Error> {
+            Ok(
+                Self::new(::serde_json::to_vec(value)?.into())
+                .with_content_type(&b"application/json"[..])
+            )
+        }
+    }
+
+    #[cfg(feature = "reqwest-blocking")]
+    impl<'a> TryFrom<&::std::option::Option<crate::v1_1_4::request::codespaces_create_with_repo_for_authenticated_user::body::Json<'a>>> for super::Content<::reqwest::blocking::Body> {
+        type Error = crate::v1_1_4::ApiError;
+
+        fn try_from(value: &::std::option::Option<crate::v1_1_4::request::codespaces_create_with_repo_for_authenticated_user::body::Json<'a>>) -> Result<Self, Self::Error> {
+            Ok(
+                Self::new(::serde_json::to_vec(value)?.into())
+                .with_content_type(&b"application/json"[..])
+            )
+        }
+    }
 }
